# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/account.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/account.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from . import user_pb2 as gateway_dot_user__pb2
from . import wandb_pb2 as gateway_dot_wandb__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/account.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x12gateway/user.proto\x1a\x13gateway/wandb.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbe\t\n\x07\x41\x63\x63ount\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x05\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12)\n\x0cintended_use\x18\x13 \x01(\tB\x13\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x12\x38\n\x13prometheus_endpoint\x18\x04 \x01(\tB\x1b\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x44\n\x1f\x61thena_cost_usage_report_bucket\x18\x05 \x01(\tB\x1b\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x38\n\x0c\x61\x63\x63ount_type\x18\x06 \x01(\x0e\x32\x1c.gateway.Account.AccountTypeB\x04\xe2\x41\x01\x01\x12\x13\n\x05\x65mail\x18\t \x01(\tB\x04\xe2\x41\x01\x02\x12,\n\x05state\x18\x07 \x01(\x0e\x32\x16.gateway.Account.StateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x08 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12?\n\rsuspend_state\x18\x0c \x01(\x0e\x32\x1d.gateway.Account.SuspendStateB\t\xe2\x41\x02\x03\x05\x98\xf1\x04\x01\x12\x30\n\x12stripe_customer_id\x18\r \x01(\tB\x14\xe2\x41\x02\x03\x05\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x12\x34\n\x0foidc_issuer_url\x18\x0e \x01(\tB\x1b\xe2\x41\x02\x04\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x33\n\x0eoidc_client_id\x18\x0f \x01(\tB\x1b\xe2\x41\x02\x04\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x33\n\x0e\x63ognito_domain\x18\x10 \x01(\tB\x1b\xe2\x41\x02\x04\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x46\n\x0cwandb_config\x18\x11 \x01(\x0b\x32\x14.gateway.WandbConfigB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x35\n\x0bupdate_time\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\"X\n\x0b\x41\x63\x63ountType\x12\x1c\n\x18\x41\x43\x43OUNT_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tDEVELOPER\x10\x01\x12\x0e\n\nENTERPRISE\x10\x02\x12\x0c\n\x08\x42USINESS\x10\x04\"S\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08UPDATING\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\"k\n\x0cSuspendState\x12\x0f\n\x0bUNSUSPENDED\x10\x00\x12\x13\n\x0f\x46\x41ILED_PAYMENTS\x10\x01\x12\x13\n\x0f\x43REDIT_DEPLETED\x10\x02\x12 \n\x1cMONTHLY_SPEND_LIMIT_EXCEEDED\x10\x03:L\xea\x41\x43\n\x18\x61pi.fireworks.ai/Account\x12\x14\x61\x63\x63ounts/{AccountId}*\x08\x61\x63\x63ounts2\x07\x61\x63\x63ount\x82\xf1\x04\x02\x18\x01\"\x90\x01\n\x14\x43reateAccountRequest\x12\'\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x10.gateway.AccountB\x04\xe2\x41\x01\x02\x12\x18\n\naccount_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x12\n\x04wait\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12!\n\x04user\x18\x04 \x01(\x0b\x32\r.gateway.UserB\x04\xe2\x41\x01\x01\"\'\n\x11GetAccountRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xa4\x01\n\x13ListAccountsRequest\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\x12,\n\x08show_all\x18\x06 \x01(\x08\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\"g\n\x14ListAccountsResponse\x12\"\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x10.gateway.Account\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"v\n\x14UpdateAccountRequest\x12\'\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x10.gateway.AccountB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"U\n\x14\x44\x65leteAccountRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12)\n\x05\x66orce\x18\x02 \x01(\x08\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLYBCZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_ACCOUNT'].fields_by_name['name']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_ACCOUNT'].fields_by_name['display_name']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['display_name']._serialized_options = b'\342A\001\005'
  _globals['_ACCOUNT'].fields_by_name['create_time']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_ACCOUNT'].fields_by_name['intended_use']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['intended_use']._serialized_options = b'\342A\001\001\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_ACCOUNT'].fields_by_name['prometheus_endpoint']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['prometheus_endpoint']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_ACCOUNT'].fields_by_name['athena_cost_usage_report_bucket']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['athena_cost_usage_report_bucket']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_ACCOUNT'].fields_by_name['account_type']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['account_type']._serialized_options = b'\342A\001\001'
  _globals['_ACCOUNT'].fields_by_name['email']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['email']._serialized_options = b'\342A\001\002'
  _globals['_ACCOUNT'].fields_by_name['state']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_ACCOUNT'].fields_by_name['status']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_ACCOUNT'].fields_by_name['suspend_state']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['suspend_state']._serialized_options = b'\342A\002\003\005\230\361\004\001'
  _globals['_ACCOUNT'].fields_by_name['stripe_customer_id']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['stripe_customer_id']._serialized_options = b'\342A\002\003\005\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_ACCOUNT'].fields_by_name['oidc_issuer_url']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['oidc_issuer_url']._serialized_options = b'\342A\002\004\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_ACCOUNT'].fields_by_name['oidc_client_id']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['oidc_client_id']._serialized_options = b'\342A\002\004\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_ACCOUNT'].fields_by_name['cognito_domain']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['cognito_domain']._serialized_options = b'\342A\002\004\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_ACCOUNT'].fields_by_name['wandb_config']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['wandb_config']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_ACCOUNT'].fields_by_name['update_time']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_ACCOUNT']._loaded_options = None
  _globals['_ACCOUNT']._serialized_options = b'\352AC\n\030api.fireworks.ai/Account\022\024accounts/{AccountId}*\010accounts2\007account\202\361\004\002\030\001'
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['account']._loaded_options = None
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['account']._serialized_options = b'\342A\001\002'
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['account_id']._loaded_options = None
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['account_id']._serialized_options = b'\342A\001\001'
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['wait']._loaded_options = None
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['wait']._serialized_options = b'\342A\001\001'
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['user']._loaded_options = None
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['user']._serialized_options = b'\342A\001\001'
  _globals['_GETACCOUNTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETACCOUNTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['show_all']._loaded_options = None
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['show_all']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_UPDATEACCOUNTREQUEST'].fields_by_name['account']._loaded_options = None
  _globals['_UPDATEACCOUNTREQUEST'].fields_by_name['account']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEACCOUNTREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEACCOUNTREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEACCOUNTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEACCOUNTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_DELETEACCOUNTREQUEST'].fields_by_name['force']._loaded_options = None
  _globals['_DELETEACCOUNTREQUEST'].fields_by_name['force']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_ACCOUNT']._serialized_start=277
  _globals['_ACCOUNT']._serialized_end=1491
  _globals['_ACCOUNT_ACCOUNTTYPE']._serialized_start=1131
  _globals['_ACCOUNT_ACCOUNTTYPE']._serialized_end=1219
  _globals['_ACCOUNT_STATE']._serialized_start=1221
  _globals['_ACCOUNT_STATE']._serialized_end=1304
  _globals['_ACCOUNT_SUSPENDSTATE']._serialized_start=1306
  _globals['_ACCOUNT_SUSPENDSTATE']._serialized_end=1413
  _globals['_CREATEACCOUNTREQUEST']._serialized_start=1494
  _globals['_CREATEACCOUNTREQUEST']._serialized_end=1638
  _globals['_GETACCOUNTREQUEST']._serialized_start=1640
  _globals['_GETACCOUNTREQUEST']._serialized_end=1679
  _globals['_LISTACCOUNTSREQUEST']._serialized_start=1682
  _globals['_LISTACCOUNTSREQUEST']._serialized_end=1846
  _globals['_LISTACCOUNTSRESPONSE']._serialized_start=1848
  _globals['_LISTACCOUNTSRESPONSE']._serialized_end=1951
  _globals['_UPDATEACCOUNTREQUEST']._serialized_start=1953
  _globals['_UPDATEACCOUNTREQUEST']._serialized_end=2071
  _globals['_DELETEACCOUNTREQUEST']._serialized_start=2073
  _globals['_DELETEACCOUNTREQUEST']._serialized_end=2158
# @@protoc_insertion_point(module_scope)



from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NodePoolBinding(_message.Message):
    __slots__ = ("account_id", "cluster_id", "node_pool_id", "create_time", "principal")
    ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    CLUSTER_ID_FIELD_NUMBER: _ClassVar[int]
    NODE_POOL_ID_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    PRINCIPAL_FIELD_NUMBER: _ClassVar[int]
    account_id: str
    cluster_id: str
    node_pool_id: str
    create_time: _timestamp_pb2.Timestamp
    principal: str
    def __init__(self, account_id: _Optional[str] = ..., cluster_id: _Optional[str] = ..., node_pool_id: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., principal: _Optional[str] = ...) -> None: ...

class CreateNodePoolBindingRequest(_message.Message):
    __slots__ = ("parent", "node_pool_binding")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    NODE_POOL_BINDING_FIELD_NUMBER: _ClassVar[int]
    parent: str
    node_pool_binding: NodePoolBinding
    def __init__(self, parent: _Optional[str] = ..., node_pool_binding: _Optional[_Union[NodePoolBinding, _Mapping]] = ...) -> None: ...

class ListNodePoolBindingsRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class ListNodePoolBindingsResponse(_message.Message):
    __slots__ = ("node_pool_bindings", "next_page_token", "total_size")
    NODE_POOL_BINDINGS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    node_pool_bindings: _containers.RepeatedCompositeFieldContainer[NodePoolBinding]
    next_page_token: str
    total_size: int
    def __init__(self, node_pool_bindings: _Optional[_Iterable[_Union[NodePoolBinding, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class DeleteNodePoolBindingRequest(_message.Message):
    __slots__ = ("node_pool_binding",)
    NODE_POOL_BINDING_FIELD_NUMBER: _ClassVar[int]
    node_pool_binding: NodePoolBinding
    def __init__(self, node_pool_binding: _Optional[_Union[NodePoolBinding, _Mapping]] = ...) -> None: ...



import copy
import logging
import os
import sys
import uvicorn
import queue
import atexit

# ANSI escape sequences for different log levels
COLORS = {
    "WARNING": "\033[93m",  # Yellow
    "INFO": "\033[94m",  # Blue
    "DEBUG": "\033[92m",  # Green
    "CRITICAL": "\033[91m",  # Red
    "ERROR": "\033[91m",  # Red
    "RESET": "\033[0m",  # Reset to default
}


class ColoredFormatter(logging.Formatter):
    def format(self, record):
        # Format string with levelname and message
        log_fmt = f"%(asctime)s {COLORS['DEBUG']}Flumina: {COLORS[record.levelname]}%(message)s{COLORS['RESET']}"
        # ISO8601 format
        formatter = logging.Formatter(log_fmt, datefmt="%Y-%m-%dT%H:%M:%S")
        return formatter.format(record)


logger = None


def get_logger():
    global logger
    if logger is None:
        # Retrieve LOGLEVEL from environment or set default to 'INFO'
        log_level = os.getenv("LOGLEVEL", "INFO").upper()

        # Important: async logging.
        # K8s redirects stderr/stdout to a file so writes to it may block if disk i/o is
        # slow. It may occur when other pods on the same node are downloading huge
        # models. Hence we do logging only on a separate thread.
        logger = logging.getLogger()
        logger.setLevel(log_level)  # Set the log level

        # Remove all previously configured handlers to enforce async logging.
        # If additional handlers are needed, please add them after import this module.
        for handler in logger.handlers[:]:
            logger.removeHandler(handler)

        log_queue = queue.Queue()
        queue_handler = logging.handlers.QueueHandler(log_queue)
        logger.addHandler(queue_handler)

        # Force all logs at level < ERROR to go to stdout, and all logs at level >= ERROR to go to stderr
        # This makes it so that unstructured log parsing by google cloud logging (formerly StackDriver)
        # doesn't spuriously count random log lines as errors
        stdout_handler = logging.StreamHandler(sys.stdout)
        stdout_handler.setFormatter(ColoredFormatter())
        stdout_handler.setLevel(logging.INFO)

        # Handler for WARNING and above -> stderr so GCP treats them as ERROR
        stderr_handler = logging.StreamHandler(sys.stderr)
        stderr_handler.setFormatter(ColoredFormatter())
        stderr_handler.setLevel(logging.WARNING)

        # Add handlers to the logger
        queue_listener = logging.handlers.QueueListener(
            log_queue, stdout_handler, stderr_handler, respect_handler_level=True
        )
        queue_listener.start()
        atexit.register(queue_listener.stop)
        # Redirect uvicorn logs to the same queue
        UVICORN_LOGGING_CONFIG = copy.deepcopy(uvicorn.config.LOGGING_CONFIG)
        for _, handler_conf in UVICORN_LOGGING_CONFIG["handlers"].items():
            handler_conf["class"] = "logging.handlers.QueueHandler"
            handler_conf["queue"] = log_queue
            del handler_conf["stream"]

    return logger



from .chat_completion import ChatCompletionV2
from .api_client import FireworksClient


class Chat:
    def __init__(self, client: FireworksClient):
        self.completions = ChatCompletionV2(client)



from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ApiKey(_message.Message):
    __slots__ = ("key_id", "display_name", "key", "create_time", "secure", "email")
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    SECURE_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    key_id: str
    display_name: str
    key: str
    create_time: _timestamp_pb2.Timestamp
    secure: bool
    email: str
    def __init__(self, key_id: _Optional[str] = ..., display_name: _Optional[str] = ..., key: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., secure: bool = ..., email: _Optional[str] = ...) -> None: ...

class CreateApiKeyRequest(_message.Message):
    __slots__ = ("parent", "api_key")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    API_KEY_FIELD_NUMBER: _ClassVar[int]
    parent: str
    api_key: ApiKey
    def __init__(self, parent: _Optional[str] = ..., api_key: _Optional[_Union[ApiKey, _Mapping]] = ...) -> None: ...

class ListApiKeysRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class ListApiKeysResponse(_message.Message):
    __slots__ = ("api_keys", "next_page_token", "total_size")
    API_KEYS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    api_keys: _containers.RepeatedCompositeFieldContainer[ApiKey]
    next_page_token: str
    total_size: int
    def __init__(self, api_keys: _Optional[_Iterable[_Union[ApiKey, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class DeleteApiKeyRequest(_message.Message):
    __slots__ = ("parent", "key_id")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    parent: str
    key_id: str
    def __init__(self, parent: _Optional[str] = ..., key_id: _Optional[str] = ...) -> None: ...

class GetInternalApiKeyRequest(_message.Message):
    __slots__ = ("parent",)
    PARENT_FIELD_NUMBER: _ClassVar[int]
    parent: str
    def __init__(self, parent: _Optional[str] = ...) -> None: ...

class UpdateApiKeyAccountRequest(_message.Message):
    __slots__ = ("old_account", "new_account")
    OLD_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    NEW_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    old_account: str
    new_account: str
    def __init__(self, old_account: _Optional[str] = ..., new_account: _Optional[str] = ...) -> None: ...



from google.protobuf import any_pb2 as _any_pb2
from ...google.rpc import status_pb2 as _status_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Operation(_message.Message):
    __slots__ = ("name", "metadata", "done", "error", "response")
    NAME_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    DONE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_FIELD_NUMBER: _ClassVar[int]
    name: str
    metadata: _any_pb2.Any
    done: bool
    error: _status_pb2.Status
    response: _any_pb2.Any
    def __init__(self, name: _Optional[str] = ..., metadata: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., done: bool = ..., error: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., response: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class GetOperationRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...



from fireworks.flumina.logger import get_logger

import contextlib
import time


@contextlib.contextmanager
def log_time(name):
    get_logger().info(f"{name}...")
    s = time.time()
    yield
    dur = time.time() - s
    get_logger().info(f"Done: {dur:.3f}s for '{name}'")



from . import deployment_pb2 as _deployment_pb2
from . import job_progress_pb2 as _job_progress_pb2
from . import options_pb2 as _options_pb2
from . import status_pb2 as _status_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import resource_pb2 as _resource_pb2
from ..google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BatchInferenceJob(_message.Message):
    __slots__ = ("name", "display_name", "create_time", "expire_time", "created_by", "state", "status", "model", "input_dataset_id", "output_dataset_id", "append_to_messages", "inference_parameters", "update_time", "ending_assistant_messages", "region", "max_replica_count", "accelerator_type", "accelerator_count", "precision", "reinforcement_fine_tuning_epoch_id", "skip_dataset_validation", "job_progress")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    EXPIRE_TIME_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    INPUT_DATASET_ID_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_DATASET_ID_FIELD_NUMBER: _ClassVar[int]
    APPEND_TO_MESSAGES_FIELD_NUMBER: _ClassVar[int]
    INFERENCE_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    ENDING_ASSISTANT_MESSAGES_FIELD_NUMBER: _ClassVar[int]
    REGION_FIELD_NUMBER: _ClassVar[int]
    MAX_REPLICA_COUNT_FIELD_NUMBER: _ClassVar[int]
    ACCELERATOR_TYPE_FIELD_NUMBER: _ClassVar[int]
    ACCELERATOR_COUNT_FIELD_NUMBER: _ClassVar[int]
    PRECISION_FIELD_NUMBER: _ClassVar[int]
    REINFORCEMENT_FINE_TUNING_EPOCH_ID_FIELD_NUMBER: _ClassVar[int]
    SKIP_DATASET_VALIDATION_FIELD_NUMBER: _ClassVar[int]
    JOB_PROGRESS_FIELD_NUMBER: _ClassVar[int]
    name: str
    display_name: str
    create_time: _timestamp_pb2.Timestamp
    expire_time: _timestamp_pb2.Timestamp
    created_by: str
    state: _status_pb2.JobState
    status: _status_pb2.Status
    model: str
    input_dataset_id: str
    output_dataset_id: str
    append_to_messages: AppendToMessages
    inference_parameters: InferenceParameters
    update_time: _timestamp_pb2.Timestamp
    ending_assistant_messages: str
    region: _deployment_pb2.Region
    max_replica_count: int
    accelerator_type: _deployment_pb2.AcceleratorType
    accelerator_count: int
    precision: _deployment_pb2.Deployment.Precision
    reinforcement_fine_tuning_epoch_id: str
    skip_dataset_validation: bool
    job_progress: _job_progress_pb2.JobProgress
    def __init__(self, name: _Optional[str] = ..., display_name: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., expire_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_by: _Optional[str] = ..., state: _Optional[_Union[_status_pb2.JobState, str]] = ..., status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., model: _Optional[str] = ..., input_dataset_id: _Optional[str] = ..., output_dataset_id: _Optional[str] = ..., append_to_messages: _Optional[_Union[AppendToMessages, _Mapping]] = ..., inference_parameters: _Optional[_Union[InferenceParameters, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., ending_assistant_messages: _Optional[str] = ..., region: _Optional[_Union[_deployment_pb2.Region, str]] = ..., max_replica_count: _Optional[int] = ..., accelerator_type: _Optional[_Union[_deployment_pb2.AcceleratorType, str]] = ..., accelerator_count: _Optional[int] = ..., precision: _Optional[_Union[_deployment_pb2.Deployment.Precision, str]] = ..., reinforcement_fine_tuning_epoch_id: _Optional[str] = ..., skip_dataset_validation: bool = ..., job_progress: _Optional[_Union[_job_progress_pb2.JobProgress, _Mapping]] = ...) -> None: ...

class InferenceParameters(_message.Message):
    __slots__ = ("max_tokens", "temperature", "top_p", "n", "extra_body", "top_k")
    MAX_TOKENS_FIELD_NUMBER: _ClassVar[int]
    TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    TOP_P_FIELD_NUMBER: _ClassVar[int]
    N_FIELD_NUMBER: _ClassVar[int]
    EXTRA_BODY_FIELD_NUMBER: _ClassVar[int]
    TOP_K_FIELD_NUMBER: _ClassVar[int]
    max_tokens: int
    temperature: float
    top_p: float
    n: int
    extra_body: str
    top_k: int
    def __init__(self, max_tokens: _Optional[int] = ..., temperature: _Optional[float] = ..., top_p: _Optional[float] = ..., n: _Optional[int] = ..., extra_body: _Optional[str] = ..., top_k: _Optional[int] = ...) -> None: ...

class AppendToMessages(_message.Message):
    __slots__ = ("unroll_multiple_responses",)
    UNROLL_MULTIPLE_RESPONSES_FIELD_NUMBER: _ClassVar[int]
    unroll_multiple_responses: bool
    def __init__(self, unroll_multiple_responses: bool = ...) -> None: ...

class GetBatchInferenceJobRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class CreateBatchInferenceJobRequest(_message.Message):
    __slots__ = ("parent", "batch_inference_job", "batch_inference_job_id")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    BATCH_INFERENCE_JOB_FIELD_NUMBER: _ClassVar[int]
    BATCH_INFERENCE_JOB_ID_FIELD_NUMBER: _ClassVar[int]
    parent: str
    batch_inference_job: BatchInferenceJob
    batch_inference_job_id: str
    def __init__(self, parent: _Optional[str] = ..., batch_inference_job: _Optional[_Union[BatchInferenceJob, _Mapping]] = ..., batch_inference_job_id: _Optional[str] = ...) -> None: ...

class ListBatchInferenceJobsRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by", "show_internal")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    SHOW_INTERNAL_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    show_internal: bool
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ..., show_internal: bool = ...) -> None: ...

class ListBatchInferenceJobsResponse(_message.Message):
    __slots__ = ("batch_inference_jobs", "next_page_token", "total_size")
    BATCH_INFERENCE_JOBS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    batch_inference_jobs: _containers.RepeatedCompositeFieldContainer[BatchInferenceJob]
    next_page_token: str
    total_size: int
    def __init__(self, batch_inference_jobs: _Optional[_Iterable[_Union[BatchInferenceJob, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class UpdateBatchInferenceJobRequest(_message.Message):
    __slots__ = ("batch_inference_job", "update_mask")
    BATCH_INFERENCE_JOB_FIELD_NUMBER: _ClassVar[int]
    UPDATE_MASK_FIELD_NUMBER: _ClassVar[int]
    batch_inference_job: BatchInferenceJob
    update_mask: _field_mask_pb2.FieldMask
    def __init__(self, batch_inference_job: _Optional[_Union[BatchInferenceJob, _Mapping]] = ..., update_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class DeleteBatchInferenceJobRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class GetBatchInferenceJobInputUploadEndpointRequest(_message.Message):
    __slots__ = ("name", "filename_to_size")
    class FilenameToSizeEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: int
        def __init__(self, key: _Optional[str] = ..., value: _Optional[int] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    FILENAME_TO_SIZE_FIELD_NUMBER: _ClassVar[int]
    name: str
    filename_to_size: _containers.ScalarMap[str, int]
    def __init__(self, name: _Optional[str] = ..., filename_to_size: _Optional[_Mapping[str, int]] = ...) -> None: ...

class GetBatchInferenceJobInputUploadEndpointResponse(_message.Message):
    __slots__ = ("filename_to_signed_urls",)
    class FilenameToSignedUrlsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    FILENAME_TO_SIGNED_URLS_FIELD_NUMBER: _ClassVar[int]
    filename_to_signed_urls: _containers.ScalarMap[str, str]
    def __init__(self, filename_to_signed_urls: _Optional[_Mapping[str, str]] = ...) -> None: ...

class ValidateBatchInferenceJobInputUploadRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class GetBatchInferenceJobOutputDownloadEndpointRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class GetBatchInferenceJobOutputDownloadEndpointResponse(_message.Message):
    __slots__ = ("filename_to_signed_urls",)
    class FilenameToSignedUrlsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    FILENAME_TO_SIGNED_URLS_FIELD_NUMBER: _ClassVar[int]
    filename_to_signed_urls: _containers.ScalarMap[str, str]
    def __init__(self, filename_to_signed_urls: _Optional[_Mapping[str, str]] = ...) -> None: ...



from ..buf.validate import validate_pb2 as _validate_pb2
from . import options_pb2 as _options_pb2
from . import status_pb2 as _status_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import resource_pb2 as _resource_pb2
from ..google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FineTuningJob(_message.Message):
    __slots__ = ("name", "display_name", "create_time", "state", "dataset", "datasets", "status", "created_by", "container_version", "model_id", "legacy_job", "text_completion", "text_classification", "conversation", "draft_model_data", "draft_model", "genie", "base_model", "warm_start_from", "early_stop", "epochs", "learning_rate", "lr_scheduler_type", "warmup_steps", "lora_alpha", "lora_rank", "lora_target_modules", "batch_size", "micro_batch_size", "mask_token", "pad_token", "cutoff_length", "wandb_url", "wandb_entity", "wandb_api_key", "wandb_project", "evaluation", "evaluation_split", "evaluation_dataset", "dependent_jobs")
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STATE_UNSPECIFIED: _ClassVar[FineTuningJob.State]
        CREATING: _ClassVar[FineTuningJob.State]
        PENDING: _ClassVar[FineTuningJob.State]
        RUNNING: _ClassVar[FineTuningJob.State]
        COMPLETED: _ClassVar[FineTuningJob.State]
        FAILED: _ClassVar[FineTuningJob.State]
        DELETING: _ClassVar[FineTuningJob.State]
    STATE_UNSPECIFIED: FineTuningJob.State
    CREATING: FineTuningJob.State
    PENDING: FineTuningJob.State
    RUNNING: FineTuningJob.State
    COMPLETED: FineTuningJob.State
    FAILED: FineTuningJob.State
    DELETING: FineTuningJob.State
    class Dataset(_message.Message):
        __slots__ = ("dataset",)
        DATASET_FIELD_NUMBER: _ClassVar[int]
        dataset: str
        def __init__(self, dataset: _Optional[str] = ...) -> None: ...
    class LegacyJob(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class TextCompletion(_message.Message):
        __slots__ = ("input_template", "output_template")
        INPUT_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
        OUTPUT_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
        input_template: str
        output_template: str
        def __init__(self, input_template: _Optional[str] = ..., output_template: _Optional[str] = ...) -> None: ...
    class TextClassification(_message.Message):
        __slots__ = ("text", "label")
        TEXT_FIELD_NUMBER: _ClassVar[int]
        LABEL_FIELD_NUMBER: _ClassVar[int]
        text: str
        label: str
        def __init__(self, text: _Optional[str] = ..., label: _Optional[str] = ...) -> None: ...
    class DraftModelData(_message.Message):
        __slots__ = ("deployment_name", "jinja_template", "cleanup_deployment")
        DEPLOYMENT_NAME_FIELD_NUMBER: _ClassVar[int]
        JINJA_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
        CLEANUP_DEPLOYMENT_FIELD_NUMBER: _ClassVar[int]
        deployment_name: str
        jinja_template: str
        cleanup_deployment: bool
        def __init__(self, deployment_name: _Optional[str] = ..., jinja_template: _Optional[str] = ..., cleanup_deployment: bool = ...) -> None: ...
    class DraftModel(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class Conversation(_message.Message):
        __slots__ = ("jinja_template",)
        JINJA_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
        jinja_template: str
        def __init__(self, jinja_template: _Optional[str] = ...) -> None: ...
    class Genie(_message.Message):
        __slots__ = ("pipeline_name",)
        PIPELINE_NAME_FIELD_NUMBER: _ClassVar[int]
        pipeline_name: str
        def __init__(self, pipeline_name: _Optional[str] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    DATASET_FIELD_NUMBER: _ClassVar[int]
    DATASETS_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    CONTAINER_VERSION_FIELD_NUMBER: _ClassVar[int]
    MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    LEGACY_JOB_FIELD_NUMBER: _ClassVar[int]
    TEXT_COMPLETION_FIELD_NUMBER: _ClassVar[int]
    TEXT_CLASSIFICATION_FIELD_NUMBER: _ClassVar[int]
    CONVERSATION_FIELD_NUMBER: _ClassVar[int]
    DRAFT_MODEL_DATA_FIELD_NUMBER: _ClassVar[int]
    DRAFT_MODEL_FIELD_NUMBER: _ClassVar[int]
    GENIE_FIELD_NUMBER: _ClassVar[int]
    BASE_MODEL_FIELD_NUMBER: _ClassVar[int]
    WARM_START_FROM_FIELD_NUMBER: _ClassVar[int]
    EARLY_STOP_FIELD_NUMBER: _ClassVar[int]
    EPOCHS_FIELD_NUMBER: _ClassVar[int]
    LEARNING_RATE_FIELD_NUMBER: _ClassVar[int]
    LR_SCHEDULER_TYPE_FIELD_NUMBER: _ClassVar[int]
    WARMUP_STEPS_FIELD_NUMBER: _ClassVar[int]
    LORA_ALPHA_FIELD_NUMBER: _ClassVar[int]
    LORA_RANK_FIELD_NUMBER: _ClassVar[int]
    LORA_TARGET_MODULES_FIELD_NUMBER: _ClassVar[int]
    BATCH_SIZE_FIELD_NUMBER: _ClassVar[int]
    MICRO_BATCH_SIZE_FIELD_NUMBER: _ClassVar[int]
    MASK_TOKEN_FIELD_NUMBER: _ClassVar[int]
    PAD_TOKEN_FIELD_NUMBER: _ClassVar[int]
    CUTOFF_LENGTH_FIELD_NUMBER: _ClassVar[int]
    WANDB_URL_FIELD_NUMBER: _ClassVar[int]
    WANDB_ENTITY_FIELD_NUMBER: _ClassVar[int]
    WANDB_API_KEY_FIELD_NUMBER: _ClassVar[int]
    WANDB_PROJECT_FIELD_NUMBER: _ClassVar[int]
    EVALUATION_FIELD_NUMBER: _ClassVar[int]
    EVALUATION_SPLIT_FIELD_NUMBER: _ClassVar[int]
    EVALUATION_DATASET_FIELD_NUMBER: _ClassVar[int]
    DEPENDENT_JOBS_FIELD_NUMBER: _ClassVar[int]
    name: str
    display_name: str
    create_time: _timestamp_pb2.Timestamp
    state: FineTuningJob.State
    dataset: str
    datasets: _containers.RepeatedCompositeFieldContainer[FineTuningJob.Dataset]
    status: _status_pb2.Status
    created_by: str
    container_version: str
    model_id: str
    legacy_job: FineTuningJob.LegacyJob
    text_completion: FineTuningJob.TextCompletion
    text_classification: FineTuningJob.TextClassification
    conversation: FineTuningJob.Conversation
    draft_model_data: FineTuningJob.DraftModelData
    draft_model: FineTuningJob.DraftModel
    genie: FineTuningJob.Genie
    base_model: str
    warm_start_from: str
    early_stop: bool
    epochs: float
    learning_rate: float
    lr_scheduler_type: str
    warmup_steps: int
    lora_alpha: int
    lora_rank: int
    lora_target_modules: _containers.RepeatedScalarFieldContainer[str]
    batch_size: int
    micro_batch_size: int
    mask_token: str
    pad_token: str
    cutoff_length: int
    wandb_url: str
    wandb_entity: str
    wandb_api_key: str
    wandb_project: str
    evaluation: bool
    evaluation_split: float
    evaluation_dataset: str
    dependent_jobs: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., display_name: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., state: _Optional[_Union[FineTuningJob.State, str]] = ..., dataset: _Optional[str] = ..., datasets: _Optional[_Iterable[_Union[FineTuningJob.Dataset, _Mapping]]] = ..., status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., created_by: _Optional[str] = ..., container_version: _Optional[str] = ..., model_id: _Optional[str] = ..., legacy_job: _Optional[_Union[FineTuningJob.LegacyJob, _Mapping]] = ..., text_completion: _Optional[_Union[FineTuningJob.TextCompletion, _Mapping]] = ..., text_classification: _Optional[_Union[FineTuningJob.TextClassification, _Mapping]] = ..., conversation: _Optional[_Union[FineTuningJob.Conversation, _Mapping]] = ..., draft_model_data: _Optional[_Union[FineTuningJob.DraftModelData, _Mapping]] = ..., draft_model: _Optional[_Union[FineTuningJob.DraftModel, _Mapping]] = ..., genie: _Optional[_Union[FineTuningJob.Genie, _Mapping]] = ..., base_model: _Optional[str] = ..., warm_start_from: _Optional[str] = ..., early_stop: bool = ..., epochs: _Optional[float] = ..., learning_rate: _Optional[float] = ..., lr_scheduler_type: _Optional[str] = ..., warmup_steps: _Optional[int] = ..., lora_alpha: _Optional[int] = ..., lora_rank: _Optional[int] = ..., lora_target_modules: _Optional[_Iterable[str]] = ..., batch_size: _Optional[int] = ..., micro_batch_size: _Optional[int] = ..., mask_token: _Optional[str] = ..., pad_token: _Optional[str] = ..., cutoff_length: _Optional[int] = ..., wandb_url: _Optional[str] = ..., wandb_entity: _Optional[str] = ..., wandb_api_key: _Optional[str] = ..., wandb_project: _Optional[str] = ..., evaluation: bool = ..., evaluation_split: _Optional[float] = ..., evaluation_dataset: _Optional[str] = ..., dependent_jobs: _Optional[_Iterable[str]] = ...) -> None: ...

class GetFineTuningJobRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class CreateFineTuningJobRequest(_message.Message):
    __slots__ = ("parent", "fine_tuning_job", "debug", "fine_tuning_job_id", "update_time")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    FINE_TUNING_JOB_FIELD_NUMBER: _ClassVar[int]
    DEBUG_FIELD_NUMBER: _ClassVar[int]
    FINE_TUNING_JOB_ID_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    parent: str
    fine_tuning_job: FineTuningJob
    debug: bool
    fine_tuning_job_id: str
    update_time: _timestamp_pb2.Timestamp
    def __init__(self, parent: _Optional[str] = ..., fine_tuning_job: _Optional[_Union[FineTuningJob, _Mapping]] = ..., debug: bool = ..., fine_tuning_job_id: _Optional[str] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ListFineTuningJobsRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class ListFineTuningJobsResponse(_message.Message):
    __slots__ = ("fine_tuning_jobs", "next_page_token", "total_size")
    FINE_TUNING_JOBS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    fine_tuning_jobs: _containers.RepeatedCompositeFieldContainer[FineTuningJob]
    next_page_token: str
    total_size: int
    def __init__(self, fine_tuning_jobs: _Optional[_Iterable[_Union[FineTuningJob, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class UpdateFineTuningJobRequest(_message.Message):
    __slots__ = ("fine_tuning_job", "update_mask")
    FINE_TUNING_JOB_FIELD_NUMBER: _ClassVar[int]
    UPDATE_MASK_FIELD_NUMBER: _ClassVar[int]
    fine_tuning_job: FineTuningJob
    update_mask: _field_mask_pb2.FieldMask
    def __init__(self, fine_tuning_job: _Optional[_Union[FineTuningJob, _Mapping]] = ..., update_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class DeleteFineTuningJobRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...



from fireworks.flumina.config import get_api_key
import httpx
from typing import Any, Dict, Optional


# Helper function to format the exception message
def handle_http_status_error(error: httpx.HTTPStatusError) -> None:
    response = error.response

    # Check if the response has a JSON content-type
    if response.headers.get("Content-Type") == "application/json":
        try:
            # Attempt to parse the JSON and use the 'message' field
            error_message = response.json().get("message", response.text)
        except ValueError:
            # Fallback to response text if JSON parsing fails
            error_message = response.text
    else:
        # Use the raw text for non-JSON responses
        error_message = response.text

    # Raise the exception with the custom error message
    raise httpx.HTTPStatusError(
        f"Error response {response.status_code} while requesting {response.url}: {error_message}",
        request=error.request,
        response=response,
    )


# **************************** Accounts ****************************


async def list_accounts() -> Dict[str, Any]:
    url = "https://api.fireworks.ai/v1/accounts"

    headers = {"Authorization": f"Bearer {get_api_key()}"}

    try:
        async with httpx.AsyncClient() as client:
            response = await client.get(url, headers=headers)
            response.raise_for_status()
            return response.json()
    except httpx.HTTPStatusError as error:
        handle_http_status_error(error)


# **************************** Models ****************************


async def list_models(
    account_id: str, pageToken: Optional[str] = None
) -> Dict[str, Any]:
    url = f"https://api.fireworks.ai/v1/accounts/{account_id}/models"
    headers = {"Authorization": f"Bearer {get_api_key()}"}
    params = {"pageToken": pageToken} if pageToken is not None else {}

    try:
        async with httpx.AsyncClient() as client:
            response = await client.get(url, headers=headers, params=params)
            response.raise_for_status()
            return response.json()
    except httpx.HTTPStatusError as error:
        handle_http_status_error(error)


async def get_model(account_id: str, model_id: str) -> Dict[str, Any]:
    url = f"https://api.fireworks.ai/v1/accounts/{account_id}/models/{model_id}"
    headers = {"Authorization": f"Bearer {get_api_key()}"}

    try:
        async with httpx.AsyncClient() as client:
            response = await client.get(url, headers=headers)
            response.raise_for_status()
            return response.json()
    except httpx.HTTPStatusError as error:
        handle_http_status_error(error)


async def create_model(
    account_id: str, model_id: str, model_data: Dict[str, Any]
) -> Dict[str, Any]:
    url = f"https://api.fireworks.ai/v1/accounts/{account_id}/models"
    headers = {
        "Authorization": f"Bearer {get_api_key()}",
        "Content-Type": "application/json",
    }
    data = {
        "modelId": model_id,
        "model": model_data,
    }

    try:
        async with httpx.AsyncClient() as client:
            response = await client.post(url, headers=headers, json=data)
            response.raise_for_status()
            return response.json()
    except httpx.HTTPStatusError as error:
        handle_http_status_error(error)


async def get_model_upload_endpoint(
    account_id: str, model_id: str, filename_to_size: Dict[str, int]
) -> Dict[str, Any]:
    url = f"https://api.fireworks.ai/v1/accounts/{account_id}/models/{model_id}:getUploadEndpoint"
    headers = {"Authorization": f"Bearer {get_api_key()}"}
    json = {
        "filenameToSize": filename_to_size,
    }

    try:
        async with httpx.AsyncClient() as client:
            response = await client.post(url, headers=headers, json=json)
            response.raise_for_status()
            return response.json()
    except httpx.HTTPStatusError as error:
        handle_http_status_error(error)


async def validate_model_upload(account_id: str, model_id: str) -> Dict[str, Any]:
    url = f"https://api.fireworks.ai/v1/accounts/{account_id}/models/{model_id}:validateUpload"
    headers = {"Authorization": f"Bearer {get_api_key()}"}

    try:
        async with httpx.AsyncClient() as client:
            response = await client.get(url, headers=headers)
            response.raise_for_status()
            return response.json()
    except httpx.HTTPStatusError as error:
        handle_http_status_error(error)


async def delete_model(account_id: str, model_id: str) -> Dict[str, Any]:
    url = f"https://api.fireworks.ai/v1/accounts/{account_id}/models/{model_id}"
    headers = {"Authorization": f"Bearer {get_api_key()}"}

    try:
        async with httpx.AsyncClient() as client:
            response = await client.delete(url, headers=headers)
            response.raise_for_status()
            return response.json()
    except httpx.HTTPStatusError as error:
        handle_http_status_error(error)


# **************************** Deployments ****************************


async def list_deployments(
    account_id: str, pageToken: Optional[str] = None
) -> Dict[str, Any]:
    url = f"https://api.fireworks.ai/v1/accounts/{account_id}/deployments"
    headers = {"Authorization": f"Bearer {get_api_key()}"}
    params = {"pageToken": pageToken} if pageToken is not None else {}

    try:
        async with httpx.AsyncClient() as client:
            response = await client.get(url, headers=headers, params=params)
            response.raise_for_status()
            return response.json()
    except httpx.HTTPStatusError as error:
        handle_http_status_error(error)


async def get_deployment(account_id: str, deployment_id: str) -> Dict[str, Any]:
    url = (
        f"https://api.fireworks.ai/v1/accounts/{account_id}/deployments/{deployment_id}"
    )
    headers = {"Authorization": f"Bearer {get_api_key()}"}

    try:
        async with httpx.AsyncClient() as client:
            response = await client.get(url, headers=headers)
            response.raise_for_status()
            return response.json()
    except httpx.HTTPStatusError as error:
        handle_http_status_error(error)


async def create_deployment(
    account_id: str, deployment_data: Dict[str, Any]
) -> Dict[str, Any]:
    url = f"https://api.fireworks.ai/v1/accounts/{account_id}/deployments"
    headers = {
        "Authorization": f"Bearer {get_api_key()}",
        "Content-Type": "application/json",
    }

    try:
        async with httpx.AsyncClient() as client:
            response = await client.post(url, headers=headers, json=deployment_data)
            response.raise_for_status()
            return response.json()
    except httpx.HTTPStatusError as error:
        handle_http_status_error(error)


async def delete_deployment(
    account_id: str, deployment_id: str, hard: Optional[bool] = None
) -> Dict[str, Any]:
    url = (
        f"https://api.fireworks.ai/v1/accounts/{account_id}/deployments/{deployment_id}"
    )
    headers = {"Authorization": f"Bearer {get_api_key()}"}
    params = {"hard": hard} if hard is not None else {}

    try:
        async with httpx.AsyncClient() as client:
            response = await client.delete(url, headers=headers, params=params)
            response.raise_for_status()
            return response.json()
    except httpx.HTTPStatusError as error:
        handle_http_status_error(error)


# ******************************* Deployed Models ********************************


async def create_deployed_model(
    account_id: str, deployed_model_data: Dict[str, Any]
) -> Dict[str, Any]:
    url = f"https://api.fireworks.ai/v1/accounts/{account_id}/deployedModels"
    headers = {
        "Authorization": f"Bearer {get_api_key()}",
        "Content-Type": "application/json",
    }

    try:
        async with httpx.AsyncClient() as client:
            response = await client.post(url, headers=headers, json=deployed_model_data)
            response.raise_for_status()
            return response.json()
    except httpx.HTTPStatusError as error:
        handle_http_status_error(error)


# Delete deployed model
async def delete_deployed_model(
    account_id: str, deployed_model_id: str
) -> Dict[str, Any]:
    url = f"https://api.fireworks.ai/v1/accounts/{account_id}/deployedModels/{deployed_model_id}"
    headers = {"Authorization": f"Bearer {get_api_key()}"}

    try:
        async with httpx.AsyncClient() as client:
            response = await client.delete(url, headers=headers)
            response.raise_for_status()
            return response.json()
    except httpx.HTTPStatusError as error:
        handle_http_status_error(error)



from fireworks.flumina.logger import get_logger

import configparser
import os


class AuthConfig:
    def __init__(
        self,
        account_id="",
        issuer_url="",
        client_id="",
        cognito_domain="",
        id_token="",
        refresh_token="",
        api_key="",
    ):
        self.account_id = account_id
        self.issuer_url = issuer_url
        self.client_id = client_id
        self.cognito_domain = cognito_domain
        self.id_token = id_token
        self.refresh_token = refresh_token
        self.api_key = api_key

    def load_from_ini(self, filepath):
        """Load configuration from an ini file without a section header."""
        config = configparser.ConfigParser()

        # Read the file by adding a dummy section header if it's missing
        with open(filepath, "r") as file:
            file_content = file.read()

        # If no section header, add a default one
        if not file_content.startswith("["):
            file_content = "[DEFAULT]\n" + file_content

        # Now parse the modified content
        config.read_string(file_content)

        # Retrieve values from the 'DEFAULT' section
        self.account_id = config.get("DEFAULT", "account_id", fallback="")
        self.issuer_url = config.get("DEFAULT", "issuer_url", fallback="")
        self.client_id = config.get("DEFAULT", "client_id", fallback="")
        self.cognito_domain = config.get("DEFAULT", "cognito_domain", fallback="")
        self.id_token = config.get("DEFAULT", "id_token", fallback="")
        self.refresh_token = config.get("DEFAULT", "refresh_token", fallback="")
        self.api_key = config.get("DEFAULT", "api_key", fallback="")


def set_api_key(api_key: str):
    """Directly set the API key in the auth.ini file by writing the `api_key` line."""
    auth_dir_path = os.path.expanduser("~/.fireworks")
    auth_ini_path = os.path.join(auth_dir_path, "auth.ini")

    # Create the directory if it doesn't exist
    if not os.path.exists(auth_dir_path):
        os.makedirs(auth_dir_path)

    # Initialize a list to hold lines of the file
    lines = []

    # Check if the file exists and load the current content
    if os.path.exists(auth_ini_path):
        with open(auth_ini_path, "r") as file:
            lines = file.readlines()

    # Look for the line starting with 'api_key' and replace it
    key_found = False
    for i, line in enumerate(lines):
        if line.startswith("api_key"):
            lines[i] = f"api_key = {api_key}\n"
            key_found = True
            break

    # If the api_key was not found, append it at the end
    if not key_found:
        lines.append(f"api_key = {api_key}\n")

    # Write the updated content back to the file
    with open(auth_ini_path, "w") as file:
        file.writelines(lines)

    get_logger().info(f"API key updated successfully in {auth_ini_path}")


def get_api_key():
    def _api_key_help():
        raise RuntimeError(
            f"Could not find Fireworks API key. Either pass FIREWORKS_API_KEY or API_KEY "
            f"environment variable, or initialize ~/.fireworks/auth.ini, "
            f"for example through `flumina set-api-key <key>`"
        )

    api_key = os.environ.get("FIREWORKS_API_KEY", None)
    if api_key is not None:
        return api_key

    api_key = os.environ.get("API_KEY", None)
    if api_key is not None:
        return api_key

    auth_ini_path = os.path.expanduser("~/.fireworks/auth.ini")
    if not os.path.exists(auth_ini_path):
        _api_key_help()

    ac = AuthConfig()
    ac.load_from_ini(auth_ini_path)

    if ac.api_key == "":
        _api_key_help()

    return ac.api_key



from typing import Any, Dict, Optional

from .api import ChatCompletionResponse, ChatCompletionStreamResponse
from .api import ChatMessage
from .base_completion import BaseCompletion
from .error import InvalidRequestError
from .api_client import FireworksClient


class ChatCompletion(BaseCompletion):
    """
    Class for handling chat completions.
    """

    endpoint = "chat/completions"
    response_class = ChatCompletionResponse
    stream_response_class = ChatCompletionStreamResponse

    @classmethod
    def _get_data_key(cls) -> str:
        return "messages"


class ChatCompletionV2(ChatCompletion):
    """
    Class for handling chat completions.
    """

    def __init__(self, client: FireworksClient):
        self._client = client

    def create(
        self,
        model,
        prompt_or_messages=None,
        request_timeout=600,
        stream=False,
        extra_headers: Optional[Dict[str, str]] = None,
        **kwargs,
    ):
        return super().create(
            model,
            prompt_or_messages,
            request_timeout,
            stream=stream,
            client=self._client,
            extra_headers=extra_headers,
            **self._validate_kwargs(kwargs),
        )

    def acreate(
        self,
        model,
        prompt_or_messages=None,
        request_timeout=600,
        stream=True,
        extra_headers: Optional[Dict[str, str]] = None,
        **kwargs,
    ):
        return super().acreate(
            model,
            prompt_or_messages,
            request_timeout,
            stream=stream,
            client=self._client,
            extra_headers=extra_headers,
            **self._validate_kwargs(kwargs),
        )

    @classmethod
    def _validate_kwargs(cls, kwargs: Dict[str, Any]) -> Dict[str, Any]:
        if "messages" in kwargs:
            messages_as_dict = []
            for message in kwargs["messages"]:
                if isinstance(message, dict):
                    messages_as_dict.append(message)
                elif isinstance(message, ChatMessage):
                    messages_as_dict.append(message.dict())
                else:
                    raise InvalidRequestError("Chat messages must be a dict or ChatMessage type")
            kwargs["messages"] = messages_as_dict
        return kwargs



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/deployment.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway/deployment.proto',
  package='gateway',
  syntax='proto3',
  serialized_options=b'Z\n./;gateway',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18gateway/deployment.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc7\x05\n\nDeployment\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x18\n\x0b\x64\x65scription\x18\x08 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x30\n\x05state\x18\x05 \x01(\x0e\x32\x19.gateway.Deployment.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\'\n\x06status\x18\x06 \x01(\x0b\x32\x0f.gateway.StatusB\x06\xe0\x41\x03\xe0\x41\x05\x12 \n\x10predict_http_uri\x18\t \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12!\n\x11min_replica_count\x18\r \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12!\n\x11max_replica_count\x18\x0e \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x1f\n\x0fmax_addon_count\x18\x10 \x01(\x05\x42\x06\xe0\x41\x03\xe0\x41\x05\x12\x1b\n\x0b\x61\x64\x64on_count\x18\x11 \x01(\x05\x42\x06\xe0\x41\x03\xe0\x41\x05\x12\x1a\n\nbase_model\x18\x12 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12+\n\x1b\x64isaggregated_prefill_count\x18\x13 \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x1e\n\x0emax_batch_size\x18\x14 \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x30\n\x0e\x61ws_deployment\x18\x15 \x01(\x0b\x32\x16.gateway.AwsDeploymentH\x00\x12\x30\n\x0egcp_deployment\x18\x16 \x01(\x0b\x32\x16.gateway.GcpDeploymentH\x00\"_\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x0c\n\x08UPDATING\x10\x05\x42\x06\n\x04type\"\x0f\n\rAwsDeployment\"\x0f\n\rGcpDeployment\"s\n\x17\x43reateDeploymentRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12,\n\ndeployment\x18\x02 \x01(\x0b\x32\x13.gateway.DeploymentB\x03\xe0\x41\x02\x12\x15\n\x08model_id\x18\x04 \x01(\tB\x03\xe0\x41\x01\")\n\x14GetDeploymentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x8a\x01\n\x16ListDeploymentsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"p\n\x17ListDeploymentsResponse\x12(\n\x0b\x64\x65ployments\x18\x01 \x03(\x0b\x32\x13.gateway.Deployment\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"G\n\x17UpdateDeploymentRequest\x12,\n\ndeployment\x18\x01 \x01(\x0b\x32\x13.gateway.DeploymentB\x03\xe0\x41\x02\",\n\x17\x44\x65leteDeploymentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"+\n\x16StartDeploymentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3'
  ,
  dependencies=[gateway_dot_status__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_DEPLOYMENT_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='gateway.Deployment.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPDATING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=734,
  serialized_end=829,
)
_sym_db.RegisterEnumDescriptor(_DEPLOYMENT_STATE)


_DEPLOYMENT = _descriptor.Descriptor(
  name='Deployment',
  full_name='gateway.Deployment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.Deployment.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='gateway.Deployment.display_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='gateway.Deployment.description', index=2,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='gateway.Deployment.create_time', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='gateway.Deployment.state', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='gateway.Deployment.status', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='predict_http_uri', full_name='gateway.Deployment.predict_http_uri', index=6,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_replica_count', full_name='gateway.Deployment.min_replica_count', index=7,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_replica_count', full_name='gateway.Deployment.max_replica_count', index=8,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_addon_count', full_name='gateway.Deployment.max_addon_count', index=9,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='addon_count', full_name='gateway.Deployment.addon_count', index=10,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_model', full_name='gateway.Deployment.base_model', index=11,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disaggregated_prefill_count', full_name='gateway.Deployment.disaggregated_prefill_count', index=12,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_batch_size', full_name='gateway.Deployment.max_batch_size', index=13,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aws_deployment', full_name='gateway.Deployment.aws_deployment', index=14,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gcp_deployment', full_name='gateway.Deployment.gcp_deployment', index=15,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DEPLOYMENT_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='gateway.Deployment.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=126,
  serialized_end=837,
)


_AWSDEPLOYMENT = _descriptor.Descriptor(
  name='AwsDeployment',
  full_name='gateway.AwsDeployment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=839,
  serialized_end=854,
)


_GCPDEPLOYMENT = _descriptor.Descriptor(
  name='GcpDeployment',
  full_name='gateway.GcpDeployment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=856,
  serialized_end=871,
)


_CREATEDEPLOYMENTREQUEST = _descriptor.Descriptor(
  name='CreateDeploymentRequest',
  full_name='gateway.CreateDeploymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.CreateDeploymentRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deployment', full_name='gateway.CreateDeploymentRequest.deployment', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='gateway.CreateDeploymentRequest.model_id', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=873,
  serialized_end=988,
)


_GETDEPLOYMENTREQUEST = _descriptor.Descriptor(
  name='GetDeploymentRequest',
  full_name='gateway.GetDeploymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetDeploymentRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=990,
  serialized_end=1031,
)


_LISTDEPLOYMENTSREQUEST = _descriptor.Descriptor(
  name='ListDeploymentsRequest',
  full_name='gateway.ListDeploymentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.ListDeploymentsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='gateway.ListDeploymentsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='gateway.ListDeploymentsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='gateway.ListDeploymentsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='gateway.ListDeploymentsRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1034,
  serialized_end=1172,
)


_LISTDEPLOYMENTSRESPONSE = _descriptor.Descriptor(
  name='ListDeploymentsResponse',
  full_name='gateway.ListDeploymentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deployments', full_name='gateway.ListDeploymentsResponse.deployments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='gateway.ListDeploymentsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_size', full_name='gateway.ListDeploymentsResponse.total_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1174,
  serialized_end=1286,
)


_UPDATEDEPLOYMENTREQUEST = _descriptor.Descriptor(
  name='UpdateDeploymentRequest',
  full_name='gateway.UpdateDeploymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deployment', full_name='gateway.UpdateDeploymentRequest.deployment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1288,
  serialized_end=1359,
)


_DELETEDEPLOYMENTREQUEST = _descriptor.Descriptor(
  name='DeleteDeploymentRequest',
  full_name='gateway.DeleteDeploymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.DeleteDeploymentRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1361,
  serialized_end=1405,
)


_STARTDEPLOYMENTREQUEST = _descriptor.Descriptor(
  name='StartDeploymentRequest',
  full_name='gateway.StartDeploymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.StartDeploymentRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1407,
  serialized_end=1450,
)

_DEPLOYMENT.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DEPLOYMENT.fields_by_name['state'].enum_type = _DEPLOYMENT_STATE
_DEPLOYMENT.fields_by_name['status'].message_type = gateway_dot_status__pb2._STATUS
_DEPLOYMENT.fields_by_name['aws_deployment'].message_type = _AWSDEPLOYMENT
_DEPLOYMENT.fields_by_name['gcp_deployment'].message_type = _GCPDEPLOYMENT
_DEPLOYMENT_STATE.containing_type = _DEPLOYMENT
_DEPLOYMENT.oneofs_by_name['type'].fields.append(
  _DEPLOYMENT.fields_by_name['aws_deployment'])
_DEPLOYMENT.fields_by_name['aws_deployment'].containing_oneof = _DEPLOYMENT.oneofs_by_name['type']
_DEPLOYMENT.oneofs_by_name['type'].fields.append(
  _DEPLOYMENT.fields_by_name['gcp_deployment'])
_DEPLOYMENT.fields_by_name['gcp_deployment'].containing_oneof = _DEPLOYMENT.oneofs_by_name['type']
_CREATEDEPLOYMENTREQUEST.fields_by_name['deployment'].message_type = _DEPLOYMENT
_LISTDEPLOYMENTSRESPONSE.fields_by_name['deployments'].message_type = _DEPLOYMENT
_UPDATEDEPLOYMENTREQUEST.fields_by_name['deployment'].message_type = _DEPLOYMENT
DESCRIPTOR.message_types_by_name['Deployment'] = _DEPLOYMENT
DESCRIPTOR.message_types_by_name['AwsDeployment'] = _AWSDEPLOYMENT
DESCRIPTOR.message_types_by_name['GcpDeployment'] = _GCPDEPLOYMENT
DESCRIPTOR.message_types_by_name['CreateDeploymentRequest'] = _CREATEDEPLOYMENTREQUEST
DESCRIPTOR.message_types_by_name['GetDeploymentRequest'] = _GETDEPLOYMENTREQUEST
DESCRIPTOR.message_types_by_name['ListDeploymentsRequest'] = _LISTDEPLOYMENTSREQUEST
DESCRIPTOR.message_types_by_name['ListDeploymentsResponse'] = _LISTDEPLOYMENTSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateDeploymentRequest'] = _UPDATEDEPLOYMENTREQUEST
DESCRIPTOR.message_types_by_name['DeleteDeploymentRequest'] = _DELETEDEPLOYMENTREQUEST
DESCRIPTOR.message_types_by_name['StartDeploymentRequest'] = _STARTDEPLOYMENTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Deployment = _reflection.GeneratedProtocolMessageType('Deployment', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMENT,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.Deployment)
  })
_sym_db.RegisterMessage(Deployment)

AwsDeployment = _reflection.GeneratedProtocolMessageType('AwsDeployment', (_message.Message,), {
  'DESCRIPTOR' : _AWSDEPLOYMENT,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.AwsDeployment)
  })
_sym_db.RegisterMessage(AwsDeployment)

GcpDeployment = _reflection.GeneratedProtocolMessageType('GcpDeployment', (_message.Message,), {
  'DESCRIPTOR' : _GCPDEPLOYMENT,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GcpDeployment)
  })
_sym_db.RegisterMessage(GcpDeployment)

CreateDeploymentRequest = _reflection.GeneratedProtocolMessageType('CreateDeploymentRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDEPLOYMENTREQUEST,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CreateDeploymentRequest)
  })
_sym_db.RegisterMessage(CreateDeploymentRequest)

GetDeploymentRequest = _reflection.GeneratedProtocolMessageType('GetDeploymentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDEPLOYMENTREQUEST,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetDeploymentRequest)
  })
_sym_db.RegisterMessage(GetDeploymentRequest)

ListDeploymentsRequest = _reflection.GeneratedProtocolMessageType('ListDeploymentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDEPLOYMENTSREQUEST,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListDeploymentsRequest)
  })
_sym_db.RegisterMessage(ListDeploymentsRequest)

ListDeploymentsResponse = _reflection.GeneratedProtocolMessageType('ListDeploymentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDEPLOYMENTSRESPONSE,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListDeploymentsResponse)
  })
_sym_db.RegisterMessage(ListDeploymentsResponse)

UpdateDeploymentRequest = _reflection.GeneratedProtocolMessageType('UpdateDeploymentRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDEPLOYMENTREQUEST,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.UpdateDeploymentRequest)
  })
_sym_db.RegisterMessage(UpdateDeploymentRequest)

DeleteDeploymentRequest = _reflection.GeneratedProtocolMessageType('DeleteDeploymentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDEPLOYMENTREQUEST,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeleteDeploymentRequest)
  })
_sym_db.RegisterMessage(DeleteDeploymentRequest)

StartDeploymentRequest = _reflection.GeneratedProtocolMessageType('StartDeploymentRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTDEPLOYMENTREQUEST,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.StartDeploymentRequest)
  })
_sym_db.RegisterMessage(StartDeploymentRequest)


DESCRIPTOR._options = None
_DEPLOYMENT.fields_by_name['name']._options = None
_DEPLOYMENT.fields_by_name['display_name']._options = None
_DEPLOYMENT.fields_by_name['description']._options = None
_DEPLOYMENT.fields_by_name['create_time']._options = None
_DEPLOYMENT.fields_by_name['state']._options = None
_DEPLOYMENT.fields_by_name['status']._options = None
_DEPLOYMENT.fields_by_name['predict_http_uri']._options = None
_DEPLOYMENT.fields_by_name['min_replica_count']._options = None
_DEPLOYMENT.fields_by_name['max_replica_count']._options = None
_DEPLOYMENT.fields_by_name['max_addon_count']._options = None
_DEPLOYMENT.fields_by_name['addon_count']._options = None
_DEPLOYMENT.fields_by_name['base_model']._options = None
_DEPLOYMENT.fields_by_name['disaggregated_prefill_count']._options = None
_DEPLOYMENT.fields_by_name['max_batch_size']._options = None
_CREATEDEPLOYMENTREQUEST.fields_by_name['parent']._options = None
_CREATEDEPLOYMENTREQUEST.fields_by_name['deployment']._options = None
_CREATEDEPLOYMENTREQUEST.fields_by_name['model_id']._options = None
_GETDEPLOYMENTREQUEST.fields_by_name['name']._options = None
_LISTDEPLOYMENTSREQUEST.fields_by_name['parent']._options = None
_LISTDEPLOYMENTSREQUEST.fields_by_name['page_size']._options = None
_LISTDEPLOYMENTSREQUEST.fields_by_name['page_token']._options = None
_LISTDEPLOYMENTSREQUEST.fields_by_name['filter']._options = None
_LISTDEPLOYMENTSREQUEST.fields_by_name['order_by']._options = None
_UPDATEDEPLOYMENTREQUEST.fields_by_name['deployment']._options = None
_DELETEDEPLOYMENTREQUEST.fields_by_name['name']._options = None
_STARTDEPLOYMENTREQUEST.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)



from . import options_pb2 as _options_pb2
from . import status_pb2 as _status_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import resource_pb2 as _resource_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PromptTuningJob(_message.Message):
    __slots__ = ("name", "display_name", "create_time", "created_by", "state", "status", "model_name", "dataset_id", "input_prompt", "output_prompt", "prompt_to_metrics", "update_time")
    class PromptToMetricsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: float
        def __init__(self, key: _Optional[str] = ..., value: _Optional[float] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    DATASET_ID_FIELD_NUMBER: _ClassVar[int]
    INPUT_PROMPT_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_PROMPT_FIELD_NUMBER: _ClassVar[int]
    PROMPT_TO_METRICS_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    name: str
    display_name: str
    create_time: _timestamp_pb2.Timestamp
    created_by: str
    state: _status_pb2.JobState
    status: _status_pb2.Status
    model_name: str
    dataset_id: str
    input_prompt: str
    output_prompt: str
    prompt_to_metrics: _containers.ScalarMap[str, float]
    update_time: _timestamp_pb2.Timestamp
    def __init__(self, name: _Optional[str] = ..., display_name: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_by: _Optional[str] = ..., state: _Optional[_Union[_status_pb2.JobState, str]] = ..., status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., model_name: _Optional[str] = ..., dataset_id: _Optional[str] = ..., input_prompt: _Optional[str] = ..., output_prompt: _Optional[str] = ..., prompt_to_metrics: _Optional[_Mapping[str, float]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class GetPromptTuningJobRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class CreatePromptTuningJobRequest(_message.Message):
    __slots__ = ("parent", "prompt_tuning_job")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PROMPT_TUNING_JOB_FIELD_NUMBER: _ClassVar[int]
    parent: str
    prompt_tuning_job: PromptTuningJob
    def __init__(self, parent: _Optional[str] = ..., prompt_tuning_job: _Optional[_Union[PromptTuningJob, _Mapping]] = ...) -> None: ...

class ListPromptTuningJobsRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class ListPromptTuningJobsResponse(_message.Message):
    __slots__ = ("prompt_tuning_jobs", "next_page_token", "total_size")
    PROMPT_TUNING_JOBS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    prompt_tuning_jobs: _containers.RepeatedCompositeFieldContainer[PromptTuningJob]
    next_page_token: str
    total_size: int
    def __init__(self, prompt_tuning_jobs: _Optional[_Iterable[_Union[PromptTuningJob, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class DeletePromptTuningJobRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...



from . import options_pb2 as _options_pb2
from . import status_pb2 as _status_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import resource_pb2 as _resource_pb2
from ..google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Cluster(_message.Message):
    __slots__ = ("name", "display_name", "create_time", "eks_cluster", "fake_cluster", "annotations", "state", "status", "is_dlde", "metering_key", "update_time")
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STATE_UNSPECIFIED: _ClassVar[Cluster.State]
        CREATING: _ClassVar[Cluster.State]
        READY: _ClassVar[Cluster.State]
        DELETING: _ClassVar[Cluster.State]
        FAILED: _ClassVar[Cluster.State]
    STATE_UNSPECIFIED: Cluster.State
    CREATING: Cluster.State
    READY: Cluster.State
    DELETING: Cluster.State
    FAILED: Cluster.State
    class AnnotationsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    EKS_CLUSTER_FIELD_NUMBER: _ClassVar[int]
    FAKE_CLUSTER_FIELD_NUMBER: _ClassVar[int]
    ANNOTATIONS_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    IS_DLDE_FIELD_NUMBER: _ClassVar[int]
    METERING_KEY_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    name: str
    display_name: str
    create_time: _timestamp_pb2.Timestamp
    eks_cluster: EksCluster
    fake_cluster: FakeCluster
    annotations: _containers.ScalarMap[str, str]
    state: Cluster.State
    status: _status_pb2.Status
    is_dlde: bool
    metering_key: str
    update_time: _timestamp_pb2.Timestamp
    def __init__(self, name: _Optional[str] = ..., display_name: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., eks_cluster: _Optional[_Union[EksCluster, _Mapping]] = ..., fake_cluster: _Optional[_Union[FakeCluster, _Mapping]] = ..., annotations: _Optional[_Mapping[str, str]] = ..., state: _Optional[_Union[Cluster.State, str]] = ..., status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., is_dlde: bool = ..., metering_key: _Optional[str] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class EksCluster(_message.Message):
    __slots__ = ("aws_account_id", "fireworks_manager_role", "region", "cluster_role", "cluster_autoscaler_role", "system_node_role", "subnet_ids", "cluster_name", "repository_name", "storage_bucket_name", "node_security_group", "metric_writer_role", "load_balancer_controller_role", "workload_identity_pool_provider_id", "inference_role")
    AWS_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    FIREWORKS_MANAGER_ROLE_FIELD_NUMBER: _ClassVar[int]
    REGION_FIELD_NUMBER: _ClassVar[int]
    CLUSTER_ROLE_FIELD_NUMBER: _ClassVar[int]
    CLUSTER_AUTOSCALER_ROLE_FIELD_NUMBER: _ClassVar[int]
    SYSTEM_NODE_ROLE_FIELD_NUMBER: _ClassVar[int]
    SUBNET_IDS_FIELD_NUMBER: _ClassVar[int]
    CLUSTER_NAME_FIELD_NUMBER: _ClassVar[int]
    REPOSITORY_NAME_FIELD_NUMBER: _ClassVar[int]
    STORAGE_BUCKET_NAME_FIELD_NUMBER: _ClassVar[int]
    NODE_SECURITY_GROUP_FIELD_NUMBER: _ClassVar[int]
    METRIC_WRITER_ROLE_FIELD_NUMBER: _ClassVar[int]
    LOAD_BALANCER_CONTROLLER_ROLE_FIELD_NUMBER: _ClassVar[int]
    WORKLOAD_IDENTITY_POOL_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    INFERENCE_ROLE_FIELD_NUMBER: _ClassVar[int]
    aws_account_id: str
    fireworks_manager_role: str
    region: str
    cluster_role: str
    cluster_autoscaler_role: str
    system_node_role: str
    subnet_ids: _containers.RepeatedScalarFieldContainer[str]
    cluster_name: str
    repository_name: str
    storage_bucket_name: str
    node_security_group: str
    metric_writer_role: str
    load_balancer_controller_role: str
    workload_identity_pool_provider_id: str
    inference_role: str
    def __init__(self, aws_account_id: _Optional[str] = ..., fireworks_manager_role: _Optional[str] = ..., region: _Optional[str] = ..., cluster_role: _Optional[str] = ..., cluster_autoscaler_role: _Optional[str] = ..., system_node_role: _Optional[str] = ..., subnet_ids: _Optional[_Iterable[str]] = ..., cluster_name: _Optional[str] = ..., repository_name: _Optional[str] = ..., storage_bucket_name: _Optional[str] = ..., node_security_group: _Optional[str] = ..., metric_writer_role: _Optional[str] = ..., load_balancer_controller_role: _Optional[str] = ..., workload_identity_pool_provider_id: _Optional[str] = ..., inference_role: _Optional[str] = ...) -> None: ...

class FakeCluster(_message.Message):
    __slots__ = ("project_id", "location", "cluster_name")
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    CLUSTER_NAME_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    location: str
    cluster_name: str
    def __init__(self, project_id: _Optional[str] = ..., location: _Optional[str] = ..., cluster_name: _Optional[str] = ...) -> None: ...

class CreateClusterRequest(_message.Message):
    __slots__ = ("parent", "cluster", "cluster_id")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    CLUSTER_FIELD_NUMBER: _ClassVar[int]
    CLUSTER_ID_FIELD_NUMBER: _ClassVar[int]
    parent: str
    cluster: Cluster
    cluster_id: str
    def __init__(self, parent: _Optional[str] = ..., cluster: _Optional[_Union[Cluster, _Mapping]] = ..., cluster_id: _Optional[str] = ...) -> None: ...

class GetClusterRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ListClustersRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class ListClustersResponse(_message.Message):
    __slots__ = ("clusters", "next_page_token", "total_size")
    CLUSTERS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    clusters: _containers.RepeatedCompositeFieldContainer[Cluster]
    next_page_token: str
    total_size: int
    def __init__(self, clusters: _Optional[_Iterable[_Union[Cluster, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class UpdateClusterRequest(_message.Message):
    __slots__ = ("cluster", "update_mask")
    CLUSTER_FIELD_NUMBER: _ClassVar[int]
    UPDATE_MASK_FIELD_NUMBER: _ClassVar[int]
    cluster: Cluster
    update_mask: _field_mask_pb2.FieldMask
    def __init__(self, cluster: _Optional[_Union[Cluster, _Mapping]] = ..., update_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class DeleteClusterRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class GetClusterConnectionInfoRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ClusterConnectionInfo(_message.Message):
    __slots__ = ("endpoint", "ca_data")
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    CA_DATA_FIELD_NUMBER: _ClassVar[int]
    endpoint: str
    ca_data: str
    def __init__(self, endpoint: _Optional[str] = ..., ca_data: _Optional[str] = ...) -> None: ...
